@@ -1,4 +1,4 @@
-## Copyright (C) 2009, 2010, 2012   Lukas F. Reichlin
+## Copyright (C) 2009, 2010, 2012, 2013   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -20,7 +20,7 @@
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 ## Created: October 2009
-## Version: 0.4
+## Version: 0.4.1
 
 function [y, t, x] = __time_response__ (response, args, sysname, plotflag)
 
@@ -175,7 +175,9 @@ function [y, t, x] = __time_response__ (response, args, sysname, plotflag)
       if (ct_idx(k))                                    # continuous-time system                                           
         for i = 1 : p                                   # for every output
           for j = 1 : cols                              # for every input (except for initial where cols=1)
-            subplot (p, cols, (i-1)*cols+j);
+            if (p != 1 && cols != 1)
+              subplot (p, cols, (i-1)*cols+j);
+            endif
             plot (t{k}, y{k}(:, i, j), style{:});
             hold on;
             grid on;
@@ -194,7 +196,9 @@ function [y, t, x] = __time_response__ (response, args, sysname, plotflag)
       else                                              # discrete-time system
         for i = 1 : p                                   # for every output
           for j = 1 : cols                              # for every input (except for initial where cols=1)
-            subplot (p, cols, (i-1)*cols+j);
+            if (p != 1 && cols != 1)
+              subplot (p, cols, (i-1)*cols+j);
+            endif
             stairs (t{k}, y{k}(:, i, j), style{:});
             hold on;
             grid on;
