@@ -1,4 +1,4 @@
-## Copyright (C) 2009   Lukas F. Reichlin
+## Copyright (C) 2009, 2013   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -16,8 +16,8 @@
 ## along with LTI Syncope.  If not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn{Function File} {[@var{K}, @var{N}, @var{gamma}, @var{rcond}] =} hinfsyn (@var{P}, @var{nmeas}, @var{ncon})
-## @deftypefnx{Function File} {[@var{K}, @var{N}, @var{gamma}, @var{rcond}] =} hinfsyn (@var{P}, @var{nmeas}, @var{ncon}, @var{gmax})
+## @deftypefn{Function File} {[@var{K}, @var{N}, @var{info}] =} hinfsyn (@var{P}, @var{nmeas}, @var{ncon})
+## @deftypefnx{Function File} {[@var{K}, @var{N}, @var{info}] =} hinfsyn (@var{P}, @var{nmeas}, @var{ncon}, @var{gmax})
 ## H-infinity control synthesis for LTI plant.
 ##
 ## @strong{Inputs}
@@ -43,15 +43,17 @@
 ## State-space model of the H-infinity (sub-)optimal controller.
 ## @item N
 ## State-space model of the lower LFT of @var{P} and @var{K}.
-## @item gamma
+## @item info
+## Structure containing additional information.
+## @item info.gamma
 ## L-infinity norm of @var{N}.
-## @item rcond
+## @item info.rcond
 ## Vector @var{rcond} contains estimates of the reciprocal condition
 ## numbers of the matrices which are to be inverted and
 ## estimates of the reciprocal condition numbers of the
 ## Riccati equations which have to be solved during the
 ## computation of the controller @var{K}.  For details,
-## see the description of the corresponding SLICOT algorithm.
+## see the description of the corresponding SLICOT routine.
 ## @end table
 ##
 ## @strong{Block Diagram}
@@ -86,7 +88,7 @@
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 ## Created: December 2009
-## Version: 0.1
+## Version: 0.2
 
 ## TODO: improve compatibility for nargin >= 4
 
@@ -144,10 +146,7 @@ function [K, varargout] = hinfsyn (P, nmeas, ncon, gmax = 1e15)
     N = lft (P, K);
     varargout{1} = N;
     if (nargout > 2)
-      varargout{2} = norm (N, inf);
-      if (nargout > 3)
-        varargout{3} = rcond;
-      endif
+      varargout{2} = struct ("gamma", norm (N, inf), "rcond", rcond);
     endif
   endif
 
